EXPORTS
	_ZN12TPacketPokerC1ER10RMBufChain @ 1 NONAME ; TPacketPoker::TPacketPoker(RMBufChain&)
	_ZN11TPacketHead21AddDestinationOptionLEPKhhhh @ 2 NONAME ; TPacketHead::AddDestinationOptionL(unsigned char const*, unsigned char, unsigned char, unsigned char)
	_ZN11TPacketHead21AddDestinationOptionLERK6TPtrC8hh @ 3 NONAME ; TPacketHead::AddDestinationOptionL(TPtrC8 const&, unsigned char, unsigned char)
	_ZN18SequenceBlockQueue10AddOrderedE10TTcpSeqNumS0_ @ 4 NONAME ; SequenceBlockQueue::AddOrdered(TTcpSeqNum, TTcpSeqNum)
	_ZN18SequenceBlockQueue12AddUnorderedE10TTcpSeqNumS0_ @ 5 NONAME ; SequenceBlockQueue::AddUnordered(TTcpSeqNum, TTcpSeqNum)
	_ZN9TChecksum3AddER10RMBufChainPK12RMBufPktInfoi @ 6 NONAME ; TChecksum::Add(RMBufChain&, RMBufPktInfo const*, int)
	_ZN9TChecksum3AddER10RMBufChaini @ 7 NONAME ; TChecksum::Add(RMBufChain&, int)
	_ZN12TPacketPoker7AdjustLEi @ 8 NONAME ; TPacketPoker::AdjustL(int)
	_ZN20CProtocolInet6Binder7BindToLEP13CProtocolBase @ 9 NONAME ; CProtocolInet6Binder::BindToL(CProtocolBase*)
	_ZN9TChecksum9CalculateEPKti @ 10 NONAME ; TChecksum::Calculate(unsigned short const*, int)
	_ZN14TimeoutFactory6CancelER8RTimeout @ 11 NONAME ; TimeoutFactory::Cancel(RTimeout&)
	_ZN18SequenceBlockQueue5ClearEv @ 12 NONAME ; SequenceBlockQueue::Clear(void)
	_ZN12RFlowContext5CloneERKS_ @ 13 NONAME ; RFlowContext::Clone(RFlowContext const&)
	_ZN12CFlowContext5CloseEv @ 14 NONAME ; CFlowContext::Close(void)
	_ZN12RFlowContext5CloseEv @ 15 NONAME ; RFlowContext::Close(void)
	_ZN12RFlowContext7ConnectEv @ 16 NONAME ; RFlowContext::Connect(void)
	_ZN12RFlowContext4CopyERS_ @ 17 NONAME ; RFlowContext::Copy(RFlowContext&)
	_ZN20CProtocolInet6Binder8DoBindToEP13CProtocolBase @ 18 NONAME ; CProtocolInet6Binder::DoBindTo(CProtocolBase*)
	_ZN11TPacketHead18ExtHdrGetOrAppendLEiRiS0_ @ 19 NONAME ; TPacketHead::ExtHdrGetOrAppendL(int, int&, int&)
	_ZN11TPacketHead19ExtHdrGetOrPrependLEiRiS0_ @ 20 NONAME ; TPacketHead::ExtHdrGetOrPrependL(int, int&, int&)
	_ZN11TPacketHead9ExtHdrGetEiRiS0_ @ 21 NONAME ; TPacketHead::ExtHdrGet(int, int&, int&)
	_ZN18SequenceBlockQueue7FindGapER10TTcpSeqNumS1_ @ 22 NONAME ; SequenceBlockQueue::FindGap(TTcpSeqNum&, TTcpSeqNum&)
	_ZN18SequenceBlockQueue4FindE10TTcpSeqNum @ 23 NONAME ; SequenceBlockQueue::Find(TTcpSeqNum)
	_ZN15RMBufPacketPeek11GetIpHeaderEv @ 24 NONAME ; RMBufPacketPeek::GetIpHeader(void)
	_ZN12RFlowContext4GrabERS_ @ 25 NONAME ; RFlowContext::Grab(RFlowContext&)
	_ZN11TTcpOptions4InitEv @ 26 NONAME ; TTcpOptions::Init(void)
	_ZNK12RFlowContext9InterfaceEv @ 27 NONAME ; RFlowContext::Interface(void) const
	_ZN14TimeoutFactory8IsActiveERK8RTimeout @ 28 NONAME ; TimeoutFactory::IsActive(RTimeout const&)
	_ZN12TPacketPoker17IsExtensionHeaderEi @ 29 NONAME ; TPacketPoker::IsExtensionHeader(int)
	_ZNK11TTcpOptions6LengthEv @ 30 NONAME ; TTcpOptions::Length(void) const
	_ZN18SequenceBlockQueue5LimitEi @ 31 NONAME ; SequenceBlockQueue::Limit(int)
	_ZN20CProtocolInet6Binder16NewHostResolverLEv @ 32 NONAME ; CProtocolInet6Binder::NewHostResolverL(void)
	_ZN14TimeoutFactory4NewLEjPvi @ 33 NONAME ; TimeoutFactory::NewL(unsigned int, void*, int)
	_ZN20CProtocolInet6Binder15NewNetDatabaseLEv @ 34 NONAME ; CProtocolInet6Binder::NewNetDatabaseL(void)
	_ZN20CProtocolInet6Binder19NewServiceResolverLEv @ 35 NONAME ; CProtocolInet6Binder::NewServiceResolverL(void)
	_ZN12RFlowContext4OpenEP12MFlowManagerRK9TSockAddrS4_jjj @ 36 NONAME ; RFlowContext::Open(MFlowManager*, TSockAddr const&, TSockAddr const&, unsigned int, unsigned int, unsigned int)
	_ZN12RFlowContext4OpenEP12MFlowManagerj @ 37 NONAME ; RFlowContext::Open(MFlowManager*, unsigned int)
	_ZN12RFlowContext4OpenERS_P12RMBufPktInfo @ 38 NONAME ; RFlowContext::Open(RFlowContext&, RMBufPktInfo*)
	_ZN11TTcpOptions13OutputOptionsEPhj @ 39 NONAME ; TTcpOptions::OutputOptions(unsigned char*, unsigned int)
	_ZN12TPacketPoker5OverLEi @ 40 NONAME ; TPacketPoker::OverL(int)
	_ZN11TTcpOptions14ProcessOptionsEPKhj @ 41 NONAME ; TTcpOptions::ProcessOptions(unsigned char const*, unsigned int)
	_ZN18SequenceBlockQueue5PruneE10TTcpSeqNum @ 42 NONAME ; SequenceBlockQueue::Prune(TTcpSeqNum)
	_ZN12RFlowContext6ReOpenEv @ 43 NONAME ; RFlowContext::ReOpen(void)
	_ZNK12CFlowContext14RetrieveOptionEjjR5TDes8 @ 44 NONAME ; CFlowContext::RetrieveOption(unsigned int, unsigned int, TDes8&) const
	_ZN12RFlowContext11SetIcmpTypeEjj @ 45 NONAME ; RFlowContext::SetIcmpType(unsigned int, unsigned int)
	_ZN12RFlowContext12SetLocalAddrERK9TSockAddr @ 46 NONAME ; RFlowContext::SetLocalAddr(TSockAddr const&)
	_ZN12RFlowContext9SetNotifyEP15MProviderNotify @ 47 NONAME ; RFlowContext::SetNotify(MProviderNotify*)
	_ZN12RFlowContext11SetProtocolEj @ 48 NONAME ; RFlowContext::SetProtocol(unsigned int)
	_ZN12RFlowContext13SetRemoteAddrERK9TSockAddr @ 49 NONAME ; RFlowContext::SetRemoteAddr(TSockAddr const&)
	_ZN12CFlowContext9SetStatusEi @ 50 NONAME ; CFlowContext::SetStatus(int)
	_ZN12CFlowContext6StatusEv @ 51 NONAME ; CFlowContext::Status(void)
	_ZN12RFlowContext6StatusEv @ 52 NONAME ; RFlowContext::Status(void)
	_ZN12CFlowContext11StoreOptionEjjRK6TDesC8 @ 53 NONAME ; CFlowContext::StoreOption(unsigned int, unsigned int, TDesC8 const&)
	_ZN12CFlowContextD1Ev @ 54 NONAME ; CFlowContext::~CFlowContext(void)
	_ZN20CProtocolInet6BinderD1Ev @ 55 NONAME ; CProtocolInet6Binder::~CProtocolInet6Binder(void)
	_ZTV20CProtocolInet6Binder @ 56 NONAME ; vtable for CProtocolInet6Binder
	_ZTV17CProtocolPosthook @ 57 NONAME ; vtable for CProtocolPosthook
	_ZN15RMBufPacketPeek6AccessEij @ 58 NONAME ; RMBufPacketPeek::Access(int, unsigned int)
	_ZN17CProtocolPosthook5BindLEP13CProtocolBasej @ 59 NONAME ; CProtocolPosthook::BindL(CProtocolBase*, unsigned int)
	_ZN17CProtocolPosthook7BindToLEP13CProtocolBase @ 60 NONAME ; CProtocolPosthook::BindToL(CProtocolBase*)
	_ZN17CProtocolPosthook9DoBindToLEP13CProtocolBase @ 61 NONAME ; CProtocolPosthook::DoBindToL(CProtocolBase*)
	_ZN17CProtocolPosthook7ProcessER10RMBufChainP13CProtocolBase @ 62 NONAME ; CProtocolPosthook::Process(RMBufChain&, CProtocolBase*)
	_ZN17CProtocolPosthook4SendER10RMBufChainP13CProtocolBase @ 63 NONAME ; CProtocolPosthook::Send(RMBufChain&, CProtocolBase*)
	_ZN17CProtocolPosthook6UnbindEP13CProtocolBasej @ 64 NONAME ; CProtocolPosthook::Unbind(CProtocolBase*, unsigned int)
	_ZN17CProtocolPosthookD1Ev @ 65 NONAME ; CProtocolPosthook::~CProtocolPosthook(void)
	_ZN13MEventService18CreateEventManagerEj @ 66 NONAME ; MEventService::CreateEventManager(unsigned int)
	_ZN17MDestinationCache14CreateDstCacheEi @ 67 NONAME ; MDestinationCache::CreateDstCache(int)
	_ZN20CProtocolInet6BinderD0Ev @ 68 NONAME ; CProtocolInet6Binder::~CProtocolInet6Binder [in-charge deleting](void)
	_ZN17CProtocolPosthookD2Ev @ 69 NONAME ; CProtocolPosthook::~CProtocolPosthook [not-in-charge](void)
	_ZN20CProtocolInet6BinderD2Ev @ 70 NONAME ; CProtocolInet6Binder::~CProtocolInet6Binder [not-in-charge](void)
	_ZN12TPacketPokerC2ER10RMBufChain @ 71 NONAME ; TPacketPoker::TPacketPoker[not-in-charge](RMBufChain&)
	_ZN12CFlowContextC2EPKvP12MFlowManagerRS_ @ 72 NONAME ; CFlowContext::CFlowContext[not-in-charge](void const*, MFlowManager*, CFlowContext&)
	_ZN17CProtocolPosthookD0Ev @ 73 NONAME ; CProtocolPosthook::~CProtocolPosthook [in-charge deleting](void)
	_ZN12CFlowContextC2EPKvP12MFlowManager @ 74 NONAME ; CFlowContext::CFlowContext[not-in-charge](void const*, MFlowManager*)
	_ZN12CFlowContextD0Ev @ 75 NONAME ; CFlowContext::~CFlowContext [in-charge deleting](void)
	_ZN12CFlowContextD2Ev @ 76 NONAME ; CFlowContext::~CFlowContext [not-in-charge](void)
	_ZTI12CFlowContext @ 77 NONAME ; typeinfo for CFlowContext
	_ZTI17CProtocolPosthook @ 78 NONAME ; typeinfo for CProtocolPosthook
	_ZTI20CProtocolInet6Binder @ 79 NONAME ; typeinfo for CProtocolInet6Binder
	_ZN16TInet6PacketBase6AccessER10RMBufChainiii @ 80 NONAME
	_ZTV12CFlowContext @ 81 NONAME ; vtable for CFlowContext
	_ZN12RFlowContext21IsNdResolutionPendingEv @ 82 NONAME

